netapp_ontap.models.nvme_namespace_clone_source API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_namespace_clone_source`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeNamespaceCloneSourceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeNamespaceCloneSource object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `name: str POST PATCH`

    The name of the clone source NVMe namespace. An NVMe namespace is located within a volume. Optionally, it can be located within a qtree in a volume.
    NVMe namespace names are paths of the form "/vol/\[/\]/\" where the qtree name is optional.
    Valid in POST and PATCH. This property is not supported. Cloning is supported through the /api/storage/storage-units endpoint. See the `POST /api/storage/storage-units` to learn more about cloning NVMe namespaces.

    Example: /vol/volume1/namespace1

  `uuid: str POST PATCH`

    The unique identifier of the clone source NVMe namespace. Valid in POST and PATCH. This property is not supported. Cloning is supported through the /api/storage/storage-units endpoint. See the `POST /api/storage/storage-units` to learn more about cloning NVMe namespaces.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412